@@ -10,8 +10,10 @@ layoutids = {"01": "en_US",
              "02": "el_GR",
              "03": "de_DE",
              "04": "fr_FR",
+             "05": "ru_RU",
              "06": "en_GB",
              "07": "Nordic",
+             "0C": "ja_JP",
              "10": "es_ES",
              "11": "it_IT",
              "12": "pt_PT",
