@@ -228,7 +228,7 @@ class RazerOrbweaverChroma(_RazerDeviceBrightnessSuspend):
     USB_PID = 0x0207
     DEDICATED_MACRO_KEYS = True
     METHODS = ['get_device_type_keypad', 'set_breath_random_effect', 'set_breath_single_effect',
-               'set_breath_dual_effect', 'set_static_effect', 'set_spectrum_effect', 'keypad_get_profile_led_red', 'keypad_set_profile_led_red', 'keypad_get_profile_led_green',
+               'set_breath_dual_effect', 'set_static_effect', 'set_spectrum_effect', 'set_wave_effect', 'keypad_get_profile_led_red', 'keypad_set_profile_led_red', 'keypad_get_profile_led_green',
                'keypad_set_profile_led_green', 'keypad_get_profile_led_blue', 'keypad_set_profile_led_blue', 'get_macros', 'delete_macro', 'add_macro', 'keypad_get_mode_modifier', 'keypad_set_mode_modifier']
 
     DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/607/607_orbweaver_chroma.png"
@@ -747,6 +747,32 @@ class RazerBlackWidowElite(_RippleKeyboard):
     }
 
 
+class RazerHuntsman(_RippleKeyboard):
+    """
+    Class for the Razer Huntsman
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*Huntsman(-if01)?-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x0227
+    HAS_MATRIX = True
+    WAVE_DIRS = (0, 1)
+    MATRIX_DIMS = [6, 22]
+    METHODS = ['get_device_type_keyboard', 'set_wave_effect', 'set_static_effect', 'set_spectrum_effect',
+               'set_reactive_effect', 'set_none_effect', 'set_breath_random_effect', 'set_breath_single_effect', 'set_breath_dual_effect',
+               'set_custom_effect', 'set_key_row', 'get_game_mode', 'set_game_mode', 'get_macro_mode', 'set_macro_mode',
+               'get_macro_effect', 'set_macro_effect', 'get_macros', 'delete_macro', 'add_macro',
+               'set_starlight_random_effect', 'set_starlight_single_effect', 'set_starlight_dual_effect',
+               'set_ripple_effect', 'set_ripple_effect_random_colour']
+
+    DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/1360/1360_huntsman-3.png"
+
+    # Deprecated - RAZER_URLS be removed in future.
+    RAZER_URLS = {
+        "top_img": "https://assets.razerzone.com/eeimages/support/products/1360/1360_huntsman-3.png"
+    }
+
+
 class RazerCynosaChroma(_RippleKeyboard):
     """
     Class for the Razer Cynosa Chroma
@@ -1097,7 +1123,7 @@ class RazerBlade2018Base(_RippleKeyboard):
     EVENT_FILE_REGEX = re.compile(r'.*Razer_Blade(-if01)?-event-kbd')
 
     USB_VID = 0x1532
-    USB_PID = 0x023b
+    USB_PID = 0x023B
     HAS_MATRIX = True
     MATRIX_DIMS = [6, 16]
     METHODS = ['get_device_type_keyboard', 'set_static_effect', 'set_spectrum_effect',
@@ -1136,6 +1162,27 @@ class RazerBladeStealth2019(_RippleKeyboard):
     }
 
 
+class RazerBladeStealthLate2019(_RippleKeyboard):
+    """
+    Class for the Razer Blade Stealth (Late 2019)
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*Razer_Blade_Stealth(-if01)?-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x024A
+    METHODS = ['get_device_type_keyboard', 'set_static_effect', 'set_spectrum_effect',
+               'set_none_effect', 'set_breath_random_effect', 'set_breath_single_effect']
+
+    DEVICE_IMAGE = "https://assets2.razerzone.com/images/blade-stealth-13/shop/stealth-l2p-1.jpg"
+
+    # Deprecated - RAZER_URLS be removed in future.
+    RAZER_URLS = {
+        "top_img": "https://assets2.razerzone.com/images/blade-stealth-13/shop/stealth-l2p-2.jpg",
+        "side_img": "https://assets2.razerzone.com/images/blade-stealth-13/shop/stealth-l2p-3.jpg",
+        "perspective_img": "https://assets2.razerzone.com/images/blade-stealth-13/shop/stealth-l2p-1.jpg"
+    }
+
+
 class RazerBlade2019Adv(_RippleKeyboard):
     """
     Class for the Razer Blade 15 (2019) Advanced
@@ -1143,7 +1190,7 @@ class RazerBlade2019Adv(_RippleKeyboard):
     EVENT_FILE_REGEX = re.compile(r'.*Razer_Blade(-if01)?-event-kbd')
 
     USB_VID = 0x1532
-    USB_PID = 0x023a
+    USB_PID = 0x023A
     HAS_MATRIX = True
     MATRIX_DIMS = [6, 16]
     METHODS = ['get_device_type_keyboard', 'set_wave_effect', 'set_static_effect', 'set_spectrum_effect',
@@ -1179,3 +1226,17 @@ class RazerBladeMid2019Mercury(_RippleKeyboard):
                'set_ripple_effect', 'set_ripple_effect_random_colour']
 
     DEVICE_IMAGE = "https://assets2.razerzone.com/images/blade-15/shop/blade15-mercury-1.jpg"
+
+
+class RazerBlade2019Base(_RippleKeyboard):
+    """
+    Class for the Razer Blade 15 (Mid 2019) Base Model
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*Razer_Blade(-if01)?-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x0246
+    METHODS = ['get_device_type_keyboard', 'set_static_effect', 'set_spectrum_effect',
+               'set_none_effect', 'set_breath_random_effect', 'set_breath_single_effect']
+
+    DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/1518/1518_blade15_mid2019-base.png"
