@@ -518,6 +518,62 @@ class RazerNagaHexV2(__RazerDeviceBrightnessSuspend):
         self.disable_notify = False
 
 
+class RazerNaga2012(__RazerDevice):
+    """
+    Class for the Razer Naga 2012
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*Razer_Razer_Naga-if0(1|2)-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x002E
+    DEDICATED_MACRO_KEYS = True
+    METHODS = ['get_device_type_mouse', 'max_dpi', 'get_dpi_xy_byte', 'set_dpi_xy_byte', 'get_poll_rate', 'set_poll_rate',
+               'get_logo_active', 'set_logo_active', 'get_scroll_active', 'set_scroll_active', 'set_backlight_active', 'get_backlight_active']
+
+    DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/products/39/razer-naga-gallery-1.png"
+
+    # Deprecated - RAZER_URLS be removed in future.
+    RAZER_URLS = {
+        "top_img": "https://assets.razerzone.com/eeimages/products/39/razer-naga-gallery-4.png",
+        "side_img": "https://assets.razerzone.com/eeimages/products/39/razer-naga-gallery-3.png",
+        "perspective_img": "https://assets.razerzone.com/eeimages/products/39/razer-naga-gallery-1.png"
+    }
+
+    DPI_MAX = 5600
+
+    def _suspend_device(self):
+        """
+        Suspend the device
+
+        Get the current brightness level, store it for later and then set the brightness to 0
+        """
+        self.suspend_args.clear()
+        self.suspend_args['active'] = (_da_get_logo_active(self), _da_get_scroll_active(self), _da_get_backlight_active(self))
+
+        # Todo make it context?
+        self.disable_notify = True
+        _da_set_logo_active(self, False)
+        _da_set_scroll_active(self, False)
+        _da_set_backlight_active(self, False)
+        self.disable_notify = False
+
+    def _resume_device(self):
+        """
+        Resume the device
+
+        Get the last known brightness and then set the brightness
+        """
+        logo_active = self.suspend_args.get('active', (True, True, True))[0]
+        scroll_active = self.suspend_args.get('active', (True, True, True))[1]
+        backlight_active = self.suspend_args.get('active', (True, True, True))[2]
+
+        self.disable_notify = True
+        _da_set_logo_active(self, logo_active)
+        _da_set_scroll_active(self, scroll_active)
+        _da_set_backlight_active(self, backlight_active)
+        self.disable_notify = False
+
+
 class RazerNagaChroma(__RazerDeviceSpecialBrightnessSuspend):
     """
     Class for the Razer Naga Chroma
@@ -567,6 +623,43 @@ class RazerNagaChroma(__RazerDeviceSpecialBrightnessSuspend):
         # self.key_manager.close()
 
 
+class RazerNagaTrinity(__RazerDeviceSpecialBrightnessSuspend):
+    """
+    Class for the Razer Naga Trinity
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*Razer_Naga_Trinity-if0(1|2)-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x0067
+    HAS_MATRIX = True
+    DEDICATED_MACRO_KEYS = True
+    MATRIX_DIMS = [1, 3]
+    METHODS = ['get_device_type_mouse', 'get_dpi_xy', 'set_dpi_xy', 'get_poll_rate', 'set_poll_rate',
+               'get_brightness', 'set_brightness', 'set_static_effect', 'max_dpi']
+
+    DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/1251/1251_razer_naga_trinity.png"
+
+    # Deprecated - RAZER_URLS be removed in future.
+    RAZER_URLS = {
+        "top_img": "https://assets.razerzone.com/eeimages/support/products/1251/1251_razer_naga_trinity.png"
+    }
+
+    DPI_MAX = 16000
+
+    def __init__(self, *args, **kwargs):
+        super(RazerNagaTrinity, self).__init__(*args, **kwargs)
+
+        # self.key_manager = _NagaHexV2KeyManager(self._device_number, self.event_files, self, use_epoll=True, testing=self._testing, should_grab_event_files=True)
+
+    def _close(self):
+        """
+        Close the key manager
+        """
+        super(RazerNagaTrinity, self)._close()
+
+        # self.key_manager.close()
+
+
 class RazerNagaHex(__RazerDevice):
     """
     Class for the Razer Naga Hex
@@ -1000,7 +1093,7 @@ class RazerOrochi2011(__RazerDeviceSpecialBrightnessSuspend):
         "perspective_img": "https://assets2.razerzone.com/images/razer-orochi/d6dd3766e7d8b5e937b4bffc8e4f9dee-Orochi-Base_gallery_7.jpg"
     }
 
-    MAX_DPI = 4000
+    DPI_MAX = 4000
 
     def _suspend_device(self):
         """
@@ -1244,3 +1337,21 @@ class RazerDeathAdderEssential(__RazerDeviceSpecialBrightnessSuspend):
         _da_set_logo_brightness(self, logo_brightness)
         _da_set_scroll_brightness(self, scroll_brightness)
         self.disable_notify = False
+
+
+class RazerDeathAdder1800(__RazerDevice):
+    """
+    Class for the Razer DeathAdder 1800
+    """
+    USB_VID = 0x1532
+    USB_PID = 0x0038
+    METHODS = ['get_device_type_mouse', 'max_dpi', 'get_dpi_xy_byte', 'set_dpi_xy_byte', 'get_poll_rate', 'set_poll_rate',
+               'get_logo_active', 'set_logo_active']
+
+    DPI_MAX = 1800
+
+    DEVICE_IMAGE = "https://rzrwarranty.s3.amazonaws.com/a7daf40ad78c9584a693e310effa956019cdcd081391f93f71a7cd36d3dc577e.png"
+
+    RAZER_URLS = {
+        "top_img": DEVICE_IMAGE
+    }
