@@ -14,6 +14,7 @@ class RazerMouse(__RazerDevice):
         # Capabilities
         self._capabilities['poll_rate'] = self._has_feature('razer.device.misc', ('getPollRate', 'setPollRate'))
         self._capabilities['dpi'] = self._has_feature('razer.device.dpi', ('getDPI', 'setDPI'))
+        self._capabilities['available_dpi'] = self._has_feature('razer.device.dpi', 'availableDPI')
 
         if self.has('dpi'):
             self._dbus_interfaces['dpi'] = _dbus.Interface(self._dbus, "razer.device.dpi")
@@ -31,6 +32,21 @@ class RazerMouse(__RazerDevice):
         else:
             return None
 
+    @property
+    def available_dpi(self) -> list:
+        """
+        Gets the available DPI
+
+        :return: Available DPI, if device has only a couple of fixed possible DPI values
+        :rtype: list or None
+        """
+        if self.has('available_dpi'):
+            dbuslist = self._dbus_interfaces['dpi'].availableDPI()
+            # Repack list from dbus ints to normal ints
+            return [int(d) for d in dbuslist]
+        else:
+            return None
+
     @property
     def dpi(self) -> tuple:
         """
@@ -54,11 +70,11 @@ class RazerMouse(__RazerDevice):
         """
         Set mouse dpi
 
-        Daemon does type validation but cant be too careful
+        Daemon does type validation but can't be too careful
         :param value: DPI X, Y tuple
         :type value: tuple
 
-        :raises ValueError: If the tuple isnt long enough or contains invalid crap
+        :raises ValueError: If the tuple isn't long enough or contains invalid crap
         :raises NotImplementedError: If function is not supported
         """
         if self.has('dpi'):
